@@ -50,8 +50,8 @@ import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.stats.Stat
 import com.unciv.models.stats.Stats
 import com.unciv.models.translations.tr
-import com.unciv.ui.utils.extensions.toPercent
-import com.unciv.ui.victoryscreen.RankingType
+import com.unciv.ui.components.extensions.toPercent
+import com.unciv.ui.screens.victoryscreen.RankingType
 import java.util.*
 import kotlin.math.max
 import kotlin.math.min
@@ -99,10 +99,6 @@ class Civilization : IsPartOfGameInfoSerialization {
     @Transient
     var viewableInvisibleUnitsTiles = setOf<Tile>()
 
-    /** Contains mapping of cities to travel mediums from ALL civilizations connected by trade routes to the capital */
-    @Transient
-    var citiesConnectedToCapitalToMediums = mapOf<City, Set<String>>()
-
     /** This is for performance since every movement calculation depends on this, see MapUnit comment */
     @Transient
     var hasActiveEnemyMovementPenalty = false
@@ -190,17 +186,16 @@ class Civilization : IsPartOfGameInfoSerialization {
     // This is basically a way to ensure our lists are immutable.
     var cities = listOf<City>()
     var citiesCreated = 0
-    var exploredTiles = HashSet<Vector2>()
+
+    // Limit camera within explored region
+    var exploredRegion = ExploredRegion()
 
     fun hasExplored(tile: Tile) = tile.isExplored(this)
 
     var lastSeenImprovement = HashMapVector2<String>()
 
     // To correctly determine "game over" condition as clarified in #4707
-    // Nullable type meant to be deprecated and converted to non-nullable,
-    // default false once we no longer want legacy save-game compatibility
-    // This parameter means they owned THEIR OWN capital btw, not other civs'.
-    var hasEverOwnedOriginalCapital: Boolean? = null
+    var hasEverOwnedOriginalCapital: Boolean = false
 
     val passableImpassables = HashSet<String>() // For Carthage-like uniques
 
@@ -242,6 +237,8 @@ class Civilization : IsPartOfGameInfoSerialization {
     @Transient
     var hasLongCountDisplayUnique = false
 
+    var statsHistory = CivRankingHistory()
+
     constructor()
 
     constructor(civName: String) {
@@ -270,11 +267,7 @@ class Civilization : IsPartOfGameInfoSerialization {
         toReturn.proximity.putAll(proximity)
         toReturn.cities = cities.map { it.clone() }
         toReturn.neutralRoads = neutralRoads
-
-        // This is the only thing that is NOT switched out, which makes it a source of ConcurrentModification errors.
-        // Cloning it by-pointer is a horrific move, since the serialization would go over it ANYWAY and still lead to concurrency problems.
-        // Cloning it by iterating on the tilemap values may seem ridiculous, but it's a perfectly thread-safe way to go about it, unlike the other solutions.
-        toReturn.exploredTiles.addAll(gameInfo.tileMap.values.asSequence().map { it.position }.filter { it in exploredTiles })
+        toReturn.exploredRegion = exploredRegion.clone()
         toReturn.lastSeenImprovement.putAll(lastSeenImprovement)
         toReturn.notifications.addAll(notifications)
         toReturn.notificationsLog.addAll(notificationsLog)
@@ -294,6 +287,7 @@ class Civilization : IsPartOfGameInfoSerialization {
         toReturn.totalFaithForContests = totalFaithForContests
         toReturn.attacksSinceTurnStart = attacksSinceTurnStart.copy()
         toReturn.hasMovedAutomatedUnits = hasMovedAutomatedUnits
+        toReturn.statsHistory = statsHistory.clone()
         return toReturn
     }
 
@@ -373,7 +367,10 @@ class Civilization : IsPartOfGameInfoSerialization {
     val cache = CivInfoTransientCache(this)
 
     fun updateStatsForNextTurn() {
+        val previousHappiness = stats.happiness
         stats.happiness = stats.getHappinessBreakdown().values.sum().roundToInt()
+        if (stats.happiness != previousHappiness)
+            for (city in cities) city.cityStats.update(updateCivStats = false)
         stats.statsForNextTurn = stats.getStatMapForNextTurn().values.reduce { a, b -> a + b }
     }
 
@@ -396,7 +393,7 @@ class Civilization : IsPartOfGameInfoSerialization {
         return newResourceSupplyList
     }
 
-    fun isCapitalConnectedToCity(city: City): Boolean = citiesConnectedToCapitalToMediums.keys.contains(city)
+    fun isCapitalConnectedToCity(city: City): Boolean = cache.citiesConnectedToCapitalToMediums.keys.contains(city)
 
 
     /**
@@ -775,15 +772,17 @@ class Civilization : IsPartOfGameInfoSerialization {
      * Removes current capital then moves capital to argument city if not null
      */
     fun moveCapitalTo(city: City?) {
-        if (cities.isNotEmpty() && getCapital() != null) {
-            val oldCapital = getCapital()!!
-            oldCapital.cityConstructions.removeBuilding(oldCapital.capitalCityIndicator())
-        }
 
-        if (city == null) return // can't move a non-existent city but we can always remove our old capital
-        // move new capital
-        city.cityConstructions.addBuilding(city.capitalCityIndicator())
-        city.isBeingRazed = false // stop razing the new capital if it was being razed
+        val oldCapital = getCapital()
+
+        // Add new capital first so the civ doesn't get stuck in a state where it has cities but no capital
+        if (city != null) {
+            // move new capital
+            city.cityConstructions.addBuilding(city.capitalCityIndicator())
+            city.isBeingRazed = false // stop razing the new capital if it was being razed
+        }
+        if (oldCapital != null)
+            oldCapital.cityConstructions.removeBuilding(oldCapital.capitalCityIndicator())
     }
 
     fun moveCapitalToNextLargest() {
