@@ -7,7 +7,6 @@ import com.unciv.logic.civilization.AlertType
 import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.civilization.NotificationCategory
 import com.unciv.logic.civilization.NotificationIcon
-import com.unciv.logic.civilization.PlayerType
 import com.unciv.logic.civilization.PopupAlert
 import com.unciv.logic.trade.Trade
 import com.unciv.logic.trade.TradeOffer
@@ -15,7 +14,7 @@ import com.unciv.logic.trade.TradeType
 import com.unciv.models.ruleset.tile.ResourceSupplyList
 import com.unciv.models.ruleset.unique.UniqueTriggerActivation
 import com.unciv.models.ruleset.unique.UniqueType
-import com.unciv.ui.utils.extensions.toPercent
+import com.unciv.ui.components.extensions.toPercent
 import kotlin.math.ceil
 import kotlin.math.max
 import kotlin.math.min
@@ -59,34 +58,38 @@ enum class DiplomacyFlags {
     RecentlyAttacked,
 }
 
-enum class DiplomaticModifiers {
-    DeclaredWarOnUs,
-    WarMongerer,
-    CapturedOurCities,
-    DeclaredFriendshipWithOurEnemies,
-    BetrayedDeclarationOfFriendship,
-    Denunciation,
-    DenouncedOurAllies,
-    RefusedToNotSettleCitiesNearUs,
-    BetrayedPromiseToNotSettleCitiesNearUs,
-    UnacceptableDemands,
-    UsedNuclearWeapons,
-    StealingTerritory,
+enum class DiplomaticModifiers(val text:String) {
+    // Negative
+    DeclaredWarOnUs("You declared war on us!"),
+    WarMongerer("Your warmongering ways are unacceptable to us."),
+    CapturedOurCities("You have captured our cities!"),
+    DeclaredFriendshipWithOurEnemies("You have declared friendship with our enemies!"),
+    BetrayedDeclarationOfFriendship("Your so-called 'friendship' is worth nothing."),
+    Denunciation("You have publicly denounced us!"),
+    DenouncedOurAllies("You have denounced our allies"),
+    RefusedToNotSettleCitiesNearUs("You refused to stop settling cities near us"),
+    BetrayedPromiseToNotSettleCitiesNearUs("You betrayed your promise to not settle cities near us"),
+    UnacceptableDemands("Your arrogant demands are in bad taste"),
+    UsedNuclearWeapons("Your use of nuclear weapons is disgusting!"),
+    StealingTerritory("You have stolen our lands!"),
+    DestroyedProtectedMinor("You destroyed City-States that were under our protection!"),
+    AttackedProtectedMinor("You attacked City-States that were under our protection!"),
+    BulliedProtectedMinor("You demanded tribute from City-States that were under our protection!"),
+    SidedWithProtectedMinor("You sided with a City-State over us"),
+
+    // Positive
+    YearsOfPeace("Years of peace have strengthened our relations."),
+    SharedEnemy("Our mutual military struggle brings us closer together."),
+    LiberatedCity("We applaud your liberation of conquered cities!"),
+    DeclarationOfFriendship("We have signed a public declaration of friendship"),
+    DeclaredFriendshipWithOurAllies("You have declared friendship with our allies"),
+    DenouncedOurEnemies("You have denounced our enemies"),
+    OpenBorders("Our open borders have brought us closer together."),
+    FulfilledPromiseToNotSettleCitiesNearUs("You fulfilled your promise to stop settling cities near us!"),
+    GaveUsUnits("You gave us units!"),
+    GaveUsGifts("We appreciate your gifts"),
+    ReturnedCapturedUnits("You returned captured units to us"),
 
-    YearsOfPeace,
-    SharedEnemy,
-    LiberatedCity,
-    DeclarationOfFriendship,
-    DeclaredFriendshipWithOurAllies,
-    DenouncedOurEnemies,
-    OpenBorders,
-    FulfilledPromiseToNotSettleCitiesNearUs,
-    GaveUsUnits,
-    DestroyedProtectedMinor,
-    AttackedProtectedMinor,
-    BulliedProtectedMinor,
-    SidedWithProtectedMinor,
-    ReturnedCapturedUnits,
 }
 
 class DiplomacyManager() : IsPartOfGameInfoSerialization {
@@ -570,6 +573,14 @@ class DiplomacyManager() : IsPartOfGameInfoSerialization {
                         civInfo.cache.updateCivResources()
                 }
             }
+
+            for (offer in trade.theirOffers.filter { it.duration <= 3 })
+            {
+                if (offer.duration == 3)
+                    civInfo.addNotification("[${offer.name}] from [$otherCivName] will end in [3] turns", NotificationCategory.Trade, otherCivName, NotificationIcon.Trade)
+                else if (offer.duration == 1)
+                    civInfo.addNotification("[${offer.name}] from [$otherCivName] will end next turn", NotificationCategory.Trade, otherCivName, NotificationIcon.Trade)
+            }
         }
     }
 
@@ -586,6 +597,7 @@ class DiplomacyManager() : IsPartOfGameInfoSerialization {
         if (openBorders > 0) addModifier(DiplomaticModifiers.OpenBorders, openBorders / 8f) // so if we both have open borders it'll grow by 0.25 per turn
         else revertToZero(DiplomaticModifiers.OpenBorders, 1 / 8f)
 
+        // Negatives
         revertToZero(DiplomaticModifiers.DeclaredWarOnUs, 1 / 8f) // this disappears real slow - it'll take 160 turns to really forget, this is war declaration we're talking about
         revertToZero(DiplomaticModifiers.WarMongerer, 1 / 2f) // warmongering gives a big negative boost when it happens but they're forgotten relatively quickly, like WWII amirite
         revertToZero(DiplomaticModifiers.CapturedOurCities, 1 / 4f) // if you captured our cities, though, that's harder to forget
@@ -593,12 +605,15 @@ class DiplomacyManager() : IsPartOfGameInfoSerialization {
         revertToZero(DiplomaticModifiers.RefusedToNotSettleCitiesNearUs, 1 / 4f)
         revertToZero(DiplomaticModifiers.BetrayedPromiseToNotSettleCitiesNearUs, 1 / 8f) // That's a bastardly thing to do
         revertToZero(DiplomaticModifiers.UnacceptableDemands, 1 / 4f)
-        revertToZero(DiplomaticModifiers.LiberatedCity, 1 / 8f)
         revertToZero(DiplomaticModifiers.StealingTerritory, 1 / 4f)
         revertToZero(DiplomaticModifiers.DenouncedOurAllies, 1 / 4f)
         revertToZero(DiplomaticModifiers.DenouncedOurEnemies, 1 / 4f)
         revertToZero(DiplomaticModifiers.Denunciation, 1 / 8f) // That's personal, it'll take a long time to fade
+
+        // Positives
         revertToZero(DiplomaticModifiers.GaveUsUnits, 1 / 4f)
+        revertToZero(DiplomaticModifiers.LiberatedCity, 1 / 8f)
+        revertToZero(DiplomaticModifiers.GaveUsGifts, 1 / 4f)
 
         setFriendshipBasedModifier()
 
@@ -814,10 +829,6 @@ class DiplomacyManager() : IsPartOfGameInfoSerialization {
         setFlag(DiplomacyFlags.DeclarationOfFriendship, 30)
         otherCivDiplomacy().setFlag(DiplomacyFlags.DeclarationOfFriendship, 30)
 
-        if (otherCiv().playerType == PlayerType.Human)
-            otherCiv().addNotification("[${civInfo.civName}] and [$otherCivName] have signed the Declaration of Friendship!",
-                NotificationCategory.Diplomacy, civInfo.civName, NotificationIcon.Diplomacy, otherCivName)
-
         for (thirdCiv in getCommonKnownCivs().filter { it.isMajorCiv() }) {
             thirdCiv.addNotification("[${civInfo.civName}] and [$otherCivName] have signed the Declaration of Friendship!",
                 NotificationCategory.Diplomacy, civInfo.civName, NotificationIcon.Diplomacy, otherCivName)
@@ -826,6 +837,8 @@ class DiplomacyManager() : IsPartOfGameInfoSerialization {
 
         for (unique in civInfo.getTriggeredUniques(UniqueType.TriggerUponDeclaringFriendship))
             UniqueTriggerActivation.triggerCivwideUnique(unique, civInfo)
+        for (unique in otherCiv().getTriggeredUniques(UniqueType.TriggerUponDeclaringFriendship))
+            UniqueTriggerActivation.triggerCivwideUnique(unique, otherCiv())
     }
 
     private fun setFriendshipBasedModifier() {
