@@ -20,10 +20,9 @@ import com.unciv.models.ruleset.unique.UniqueTarget
 import com.unciv.models.ruleset.unique.UniqueTriggerActivation
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
-import com.unciv.ui.utils.MayaCalendar
-import com.unciv.ui.utils.extensions.toPercent
-import com.unciv.ui.utils.extensions.withItem
-import java.util.*
+import com.unciv.ui.components.MayaCalendar
+import com.unciv.ui.components.extensions.toPercent
+import com.unciv.ui.components.extensions.withItem
 import kotlin.math.ceil
 import kotlin.math.max
 import kotlin.math.min
@@ -153,13 +152,13 @@ class TechManager : IsPartOfGameInfoSerialization {
     //endregion
 
     fun getRequiredTechsToDestination(destinationTech: Technology): List<Technology> {
-        val prerequisites = Stack<Technology>()
+        val prerequisites = mutableListOf<Technology>()
 
         val checkPrerequisites = ArrayDeque<Technology>()
         checkPrerequisites.add(destinationTech)
 
         while (!checkPrerequisites.isEmpty()) {
-            val techToCheck = checkPrerequisites.pop()
+            val techToCheck = checkPrerequisites.removeFirst()
             // future tech can have been researched even when we're researching it,
             // so...if we skip it we'll end up with 0 techs in the "required techs", which will mean that we don't have anything to research. Yeah.
             if (!techToCheck.isContinuallyResearchable() &&
@@ -256,6 +255,7 @@ class TechManager : IsPartOfGameInfoSerialization {
             techsToResearch.remove(techName)
         else
             repeatingTechsResearched++
+        techsInProgress.remove(techName)
         researchedTechnologies = researchedTechnologies.withItem(newTech)
         addTechToTransients(newTech)
 
@@ -271,10 +271,11 @@ class TechManager : IsPartOfGameInfoSerialization {
 
         updateTransientBooleans()
         for (city in civInfo.cities) {
+            city.cityStats.update()
             city.updateCitizens = true
         }
 
-        if(!civInfo.isSpectator())
+        if (!civInfo.isSpectator())
             civInfo.addNotification("Research of [$techName] has completed!", TechAction(techName),
                 NotificationCategory.General,
                 NotificationIcon.Science, techName)
@@ -392,7 +393,7 @@ class TechManager : IsPartOfGameInfoSerialization {
             for (policyBranch in getRuleset().policyBranches.values.filter {
                 it.era == currentEra.name && civInfo.policies.isAdoptable(it)
             }) {
-                if(!civInfo.isSpectator())
+                if (!civInfo.isSpectator())
                     civInfo.addNotification(
                         "[${policyBranch.name}] policy branch unlocked!",
                         NotificationCategory.General,
