@@ -4,7 +4,6 @@ import com.badlogic.gdx.math.Vector2
 import com.unciv.Constants
 import com.unciv.logic.IsPartOfGameInfoSerialization
 import com.unciv.logic.automation.unit.UnitAutomation
-import com.unciv.logic.automation.unit.WorkerAutomation
 import com.unciv.logic.battle.Battle
 import com.unciv.logic.battle.MapUnitCombatant
 import com.unciv.logic.city.City
@@ -23,7 +22,7 @@ import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.ruleset.unit.UnitType
 import com.unciv.models.stats.Stats
-import com.unciv.ui.utils.extensions.filterAndLogic
+import com.unciv.ui.components.extensions.filterAndLogic
 import java.text.DecimalFormat
 import kotlin.math.pow
 
@@ -43,7 +42,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
     lateinit var currentTile: Tile
 
     @Transient
-    val movement = UnitMovementAlgorithms(this)
+    val movement = UnitMovement(this)
 
     @Transient
     val upgrade = UnitUpgradeManager(this)
@@ -110,9 +109,15 @@ class MapUnit : IsPartOfGameInfoSerialization {
     var isTransported: Boolean = false
     var turnsFortified = 0
 
+    // Old, to be deprecated
+    @Deprecated("As of 4.5.3")
     var abilityUsesLeft: HashMap<String, Int> = hashMapOf()
+    @Deprecated("As of 4.5.3")
     var maxAbilityUses: HashMap<String, Int> = hashMapOf()
 
+    // New - track only *how many have been used*, derive max from uniques, left = max - used
+    var abilityToTimesUsed: HashMap<String, Int> = hashMapOf()
+
     var religion: String? = null
     var religiousStrengthLost = 0
 
@@ -174,6 +179,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
         toReturn.isTransported = isTransported
         toReturn.abilityUsesLeft.putAll(abilityUsesLeft)
         toReturn.maxAbilityUses.putAll(maxAbilityUses)
+        toReturn.abilityToTimesUsed.putAll(abilityToTimesUsed)
         toReturn.religion = religion
         toReturn.religiousStrengthLost = religiousStrengthLost
         toReturn.movementMemories = movementMemories.copy()
@@ -290,7 +296,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
     /**
      * Update this unit's cache of viewable tiles and its civ's as well.
      */
-    fun updateVisibleTiles(updateCivViewableTiles:Boolean = true) {
+    fun updateVisibleTiles(updateCivViewableTiles:Boolean = true, explorerPosition: Vector2? = null) {
         val oldViewableTiles = viewableTiles
 
         viewableTiles = when {
@@ -302,7 +308,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
 
         // Set equality automatically determines if anything changed - https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-abstract-set/equals.html
         if (updateCivViewableTiles && oldViewableTiles != viewableTiles)
-            civ.cache.updateViewableTiles()
+            civ.cache.updateViewableTiles(explorerPosition)
     }
 
     fun isActionUntilHealed() = action?.endsWith("until healed") == true
@@ -425,6 +431,11 @@ class MapUnit : IsPartOfGameInfoSerialization {
         updateUniques()
     }
 
+    fun getTriggeredUniques(trigger: UniqueType,
+                            stateForConditionals: StateForConditionals = StateForConditionals(civInfo = civ, unit = this)): Sequence<Unique> {
+        return getUniques().filter { it.conditionals.any { it.type == trigger } && it.conditionalsApply(stateForConditionals) }
+    }
+
     fun useMovementPoints(amount: Float) {
         turnsFortified = 0
         currentMovement -= amount
@@ -466,7 +477,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
             return
         }
 
-        if (isAutomated()) WorkerAutomation.automateWorkerAction(this)
+        if (isAutomated()) UnitAutomation.automateUnitMoves(this)
 
         if (isExploring()) UnitAutomation.automatedExplore(this)
     }
@@ -555,11 +566,11 @@ class MapUnit : IsPartOfGameInfoSerialization {
         for (unique in civ.getMatchingUniques(UniqueType.ProvidesGoldWheneverGreatPersonExpended)) {
             gainedStats.gold += (100 * civ.gameInfo.speed.goldCostModifier).toInt()
         }
+        val speedModifiers = civ.gameInfo.speed.statCostModifiers
         for (unique in civ.getMatchingUniques(UniqueType.ProvidesStatsWheneverGreatPersonExpended)) {
-            val uniqueStats = unique.stats
-            val speedModifiers = civ.gameInfo.speed.statCostModifiers
-            for (stat in uniqueStats) {
-                uniqueStats[stat.key] = stat.value * speedModifiers[stat.key]!!
+            val uniqueStats = unique.stats.clone()
+            for ((stat, value) in uniqueStats) {
+                uniqueStats[stat] = value * speedModifiers[stat]!!
             }
             gainedStats.add(uniqueStats)
         }
@@ -607,7 +618,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
             promotions.addPromotion(promotion, true)
         }
 
-        updateVisibleTiles()
+        updateVisibleTiles(true, currentTile.position)
     }
 
     fun putInTile(tile: Tile) {
@@ -810,12 +821,12 @@ class MapUnit : IsPartOfGameInfoSerialization {
         return civ.gameInfo.religions[religion]!!.getReligionDisplayName()
     }
 
-    fun religiousActionsUnitCanDo(): Sequence<String> {
+    fun limitedActionsUnitCanDo(): Sequence<String> {
         return getMatchingUniques(UniqueType.CanActionSeveralTimes)
             .map { it.params[0] }
     }
 
-    fun canDoReligiousAction(action: String): Boolean {
+    fun canDoLimitedAction(action: String): Boolean {
         return getMatchingUniques(UniqueType.CanActionSeveralTimes).any { it.params[0] == action }
     }
 
@@ -828,7 +839,7 @@ class MapUnit : IsPartOfGameInfoSerialization {
     }
 
     fun setupAbilityUses(buildCity: City? = null) {
-        for (action in religiousActionsUnitCanDo()) {
+        for (action in limitedActionsUnitCanDo()) {
             val baseAmount = getBaseMaxActionUses(action)
             val additional =
                 if (buildCity == null) 0
