@@ -4,6 +4,7 @@ import com.badlogic.gdx.Gdx
 import com.badlogic.gdx.files.FileHandle
 import com.unciv.json.fromJsonFile
 import com.unciv.json.json
+import com.unciv.logic.civilization.diplomacy.DiplomaticModifiers
 import com.unciv.logic.civilization.managers.SpyAction
 import com.unciv.models.metadata.BaseRuleset
 import com.unciv.models.metadata.LocaleCode
@@ -20,6 +21,7 @@ import com.unciv.models.ruleset.unique.*
 import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.ruleset.unit.Promotion
 import com.unciv.models.ruleset.unit.UnitType
+import com.unciv.ui.components.KeyboardBinding
 import com.unciv.utils.debug
 import java.io.File
 import java.lang.reflect.Field
@@ -85,10 +87,19 @@ object TranslationFileWriter {
         val linesToTranslate = mutableListOf<String>()
 
         if (modFolder == null) { // base game
-            val templateFile = getFileHandle(modFolder, templateFileLocation) // read the template
+            val templateFile = getFileHandle(null, templateFileLocation) // read the template
             if (templateFile.exists())
                 linesToTranslate.addAll(templateFile.reader(TranslationFileReader.charset).readLines())
 
+            linesToTranslate += "\n\n#################### Lines from Unique Types #######################\n"
+            for (uniqueType in UniqueType.values()) {
+                val deprecationAnnotation = uniqueType.getDeprecationAnnotation()
+                if (deprecationAnnotation != null) continue
+                if (uniqueType.flags.contains(UniqueFlag.HiddenToUsers)) continue
+
+                linesToTranslate += "${uniqueType.getTranslatable()} = "
+            }
+
             for (uniqueParameterType in UniqueParameterType.values()) {
                 val strings = uniqueParameterType.getTranslationWriterStringsForOutput()
                 if (strings.isEmpty()) continue
@@ -96,6 +107,23 @@ object TranslationFileWriter {
                 linesToTranslate.addAll(strings.map { "$it = " })
             }
 
+            for (uniqueTarget in UniqueTarget.values())
+                linesToTranslate += "$uniqueTarget = "
+
+            linesToTranslate += "\n\n#################### Lines from spy actions #######################\n"
+            for (spyAction in SpyAction.values()) {
+                linesToTranslate += "$spyAction = "
+            }
+
+            linesToTranslate += "\n\n#################### Lines from diplomatic modifiers #######################\n"
+            for (diplomaticModifier in DiplomaticModifiers.values())
+                linesToTranslate += "${diplomaticModifier.text} = "
+
+            linesToTranslate += "\n\n#################### Lines from key bindings #######################\n"
+            for (binding in KeyboardBinding.values()) {
+                linesToTranslate += "${binding.label} = "
+            }
+
             for (baseRuleset in BaseRuleset.values()) {
                 val generatedStringsFromBaseRuleset =
                         GenerateStringsFromJSONs(Gdx.files.local("jsons/${baseRuleset.fullName}"))
@@ -112,29 +140,11 @@ object TranslationFileWriter {
 
         for ((key, value) in fileNameToGeneratedStrings) {
             if (value.isEmpty()) continue
-            linesToTranslate.add("\n#################### Lines from $key ####################\n")
+            linesToTranslate += "\n#################### Lines from $key ####################\n"
             linesToTranslate.addAll(value)
         }
         fileNameToGeneratedStrings.clear()  // No longer needed
 
-        if (modFolder == null) { // base game
-            linesToTranslate.add("\n\n#################### Lines from Unique Types #######################\n")
-            for (uniqueType in UniqueType.values()) {
-                val deprecationAnnotation = uniqueType.getDeprecationAnnotation()
-                if (deprecationAnnotation != null) continue
-                if (uniqueType.flags.contains(UniqueFlag.HiddenToUsers)) continue
-
-                linesToTranslate.add("${uniqueType.getTranslatable()} = ")
-            }
-
-            for (uniqueTarget in UniqueTarget.values())
-                linesToTranslate.add("$uniqueTarget = ")
-
-            for (spyAction in SpyAction.values()) {
-                linesToTranslate.add("$spyAction = ")
-            }
-        }
-
         var countOfTranslatableLines = 0
         val countOfTranslatedLines = HashMap<String, Int>()
 
